==> apache-nuttx-12.0.0.tar.gz: nuttx/libs/libc/sched/task_testcancel.c <==
/****************************************************************************
 * libs/libc/sched/task_testcancel.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <sched.h>

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: task_testcancel
 *
 * Description:
 *   The task_testcancel() function creates a cancellation point in the
 *   calling thread. The task_testcancel() function has no effect if
 *   cancelability is disabled
 *
 ****************************************************************************/

void task_testcancel(void)
{
}

==> apache-nuttx-12.2.0.tar.gz: nuttx/libs/libc/sched/task_testcancel.c <==
/****************************************************************************
 * libs/libc/sched/task_testcancel.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <sched.h>

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: task_testcancel
 *
 * Description:
 *   The task_testcancel() function creates a cancellation point in the
 *   calling thread. The task_testcancel() function has no effect if
 *   cancellability is disabled
 *
 ****************************************************************************/

void task_testcancel(void)
{
}
